@@ -35,11 +35,34 @@
 #include "gnuvd.h"
 
 static const char* VANDALE_SERVER = "www.vandale.nl";
-static const char* VANDALE_URI    = "http://www.vandale.nl/opzoeken/woordenboek";
 static const char* VANDALE_PORT   = "80";
 
-static char* HTTP_PROXY_HOST = NULL;
-static char* HTTP_PROXY_PORT = NULL;
+
+/*
+ * http stuff; the HTTP_REQUEST / HTTP_REQUEST_PROXY have _2_
+ * %s fields (for the search term)
+ */
+#define HTTP_HEADERS \
+"Host: www.vandale.nl\r\n" \
+"User-Agent:  GNUVD/" VERSION "\r\n" \
+"Accept: text/xml,application/xml,application/xhtml+xml,text/html;" \
+"q=0.9,text/plain;q=0.8,video/x-mng,image/png,image/jpeg,image/gif;" \
+"q=0.2,text/css,*/*;q=0.1\r\n" \
+"Accept-Language: nl, en\r\n" \
+"Accept-Charset: ISO-8859-1\r\n" \
+"Keep-Alive: 300\r\n" \
+"Connection: keep-alive\r\n" \
+"Referer: http://www.vandale.nl/opzoeken/woordenboek/?zoekwoord=%s\r\n" \
+"\r\n"
+
+#define HTTP_REQUEST \
+"GET /opzoeken/woordenboek/?zoekwoord=%s HTTP/1.1\r\n" HTTP_HEADERS
+
+#define HTTP_REQUEST_PROXY \
+"GET http://www.vandale.nl/opzoeken/woordenboek/?zoekwoord=%s HTTP/1.1\r\n" HTTP_HEADERS
+
+static char* HTTP_PROXY_HOST      = NULL;
+static char* HTTP_PROXY_PORT      = NULL;
 
 static struct addrinfo*   vd_resolve              (const char* dnsname, const char* server, 
 						   VDError *ex);
@@ -51,8 +74,8 @@ static char*              vd_get_http_results     (int sock, size_t *bytes_read,
 						   VDCallback vd_callback, 
 					           size_t chunk_size, VDError *ex);
 static void               vd_filter_http_buffer   (Buffer *buffer, VDError *ex);
-static int                vd_parse_http_proxy     (const char* http_proxy, char **host, 
-						   char **port);
+static void               vd_parse_http_proxy     (const char* http_proxy, char **host, 
+						   char **port, VDError *ex);
 
 #if HAVE_HSTRERROR
 /*OK*/
@@ -79,17 +102,15 @@ VDQuery*
 vd_query_new (const char *word, VDError *ex)
 {
 	VDQuery *vd_query;
-
+	
 	assert (word);
 	assert (ex);
-	
+
 	if (getenv ("http_proxy")) {
-		if (vd_parse_http_proxy (getenv ("http_proxy"), 
-					 &HTTP_PROXY_HOST, 
-					 &HTTP_PROXY_PORT) != 0) {
-			*ex = VD_ERR_PROXY;
+		vd_parse_http_proxy (getenv ("http_proxy"),&HTTP_PROXY_HOST, 
+				     &HTTP_PROXY_PORT, ex);
+		if (*ex != VD_ERR_OK) 
 			return NULL;
-		}
 	}
 
 	vd_query = (VDQuery*) malloc (sizeof(VDQuery));
@@ -236,19 +257,20 @@ vd_query_perform_progressive (const VDQuery *vd_query, VDCallback call_back,
 static struct addrinfo* 
 vd_resolve (const char* dnsname, const char* server, VDError *ex)
 {
-	struct addrinfo hints, *ai;
-	int err;
+	struct addrinfo hints;
+	struct addrinfo *ai    = NULL;
 
 	memset (&hints, 0, sizeof(hints));
+	
 	hints.ai_family   = AF_UNSPEC;
 	hints.ai_socktype = SOCK_STREAM;
 	hints.ai_protocol = IPPROTO_TCP;
 	
-	err = getaddrinfo (dnsname, server, &hints, &ai);
-	if (err || !ai) {
+	if (getaddrinfo (dnsname, server, &hints, &ai) != 0) {
 		*ex = VD_ERR_DNS;
 		return NULL;
 	}
+	
 	return ai;
 }
 
@@ -277,45 +299,20 @@ vd_socket_to_site (const struct addrinfo *dest_sa, VDError *ex)
 static char*
 vd_construct_http_query (const char *search_term, VDError *ex)
 {
-	static const char *request_template = 
-		"GET %s/opzoeken/woordenboek/?zoekwoord=%s HTTP/1.1\r\n"
-		"Host: www.vandale.nl\r\n"
-		"User-Agent:  GNUVD/" VERSION "\r\n"
-		"Accept: text/xml,application/xml,application/xhtml+xml,text/html;"
-		"q=0.9,text/plain;q=0.8,video/x-mng,image/png,image/jpeg,image/gif;"
-		"q=0.2,text/css,*/*;q=0.1\r\n"
-		"Accept-Language: nl, en\r\n"
-		"Accept-Charset: ISO-8859-1\r\n"
-		"Keep-Alive: 300\r\n"
-		"Connection: keep-alive\r\n"
-		"Referer: http://www.vandale.nl/opzoeken/woordenboek/?zoekwoord=%s\r\n"
-		"\r\n";
-	
 	char *query;
-	const char *server;  
-	int  query_size, result;
-
-	/* use proxy? */
-	server = (HTTP_PROXY_HOST) ? VANDALE_URI : "";
-
-	query_size = strlen (request_template) + 
-		2 * strlen (search_term) + 
-		strlen (server);
+	int len= strlen(HTTP_PROXY_HOST ? HTTP_REQUEST_PROXY : HTTP_REQUEST) + 
+		strlen(search_term) * 2;
 	
-	query = (char*) malloc (query_size + 1);
+	query = (char*) malloc (len + 1);
 	if (!query) {
-		*ex   = VD_ERR_MEM;
+		*ex = VD_ERR_MEM;
 		return NULL;
-	}
+	}	
 	
-	result = snprintf (query, query_size, request_template,
-			   server,search_term,search_term);
-	if (result == -1) {
-		free (query);
-		*ex   = VD_ERR_MEM;
-		return NULL;
-	} else 
-		return query;
+	snprintf (query, len, (HTTP_PROXY_HOST ? HTTP_REQUEST_PROXY : HTTP_REQUEST),
+		  search_term,search_term);
+	
+	return query;
 }
 
 
@@ -338,6 +335,7 @@ vd_get_http_results (int sock, size_t *bytes_read,
 	char *buf;
 	int result;
 
+
 	buf = (char*) malloc (max_buf);
 	if (!buf) {
 		*ex   = VD_ERR_MEM;
@@ -372,18 +370,17 @@ vd_filter_http_buffer (Buffer *http_buffer, VDError* ex)
 	int pos;
 	char *data;
 	
-	static const char* resultaat   = "RESULTAAT (maximaal 20 woorden)";
+	static const char* big         = "<BIG>";
 	static const char* opnieuw     = "Opnieuw/verfijnd zoeken";
 	static const char* unavailable = "onderhoudswerkzaamheden";
+
+	assert (http_buffer);
+	assert (ex);
 	
-	pos = buffer_find (http_buffer, resultaat, strlen(resultaat)) + strlen(resultaat);
-	if (pos <  buffer_end (http_buffer))
-		while (pos < buffer_end (http_buffer) && isspace(buffer_data(http_buffer)[pos]))
-			++pos;
-	
-	if (pos <  buffer_end (http_buffer)) 
+	pos = buffer_find (http_buffer, big, strlen(big));
+	if (pos <  buffer_end (http_buffer)) {
 		buffer_erase (http_buffer, 0, pos);
-	else {
+	} else {
 		/* nothing was found or not available*/
 		pos = buffer_find (http_buffer, unavailable, strlen(unavailable));
 		if (pos < buffer_end (http_buffer)) 
@@ -412,29 +409,26 @@ vd_filter_http_buffer (Buffer *http_buffer, VDError* ex)
 	buffer_erase (http_buffer, pos + 1, 
 		      buffer_length (http_buffer) - pos - 2);
 	
-	if (buffer_length (http_buffer) < min_length) {
-		
+	if (buffer_length (http_buffer) < min_length)
 		*ex = VD_ERR_NOT_FOUND;
-	}
 } 
 
 
 
-static int 
-vd_parse_http_proxy (const char* http_proxy, char **host, char **port)
+static void
+vd_parse_http_proxy (const char* http_proxy, char **host, char **port, VDError *ex)
 {
 	int i;
 	int len;
 
-	assert (*host);
-	assert (*port);
+	assert (host);
+	assert (port);
+	assert (ex);
 
-	if (!http_proxy)
-		return 1;
-
-	/* string too short */
-	if (!(len = strlen (http_proxy)))
-		return 1;
+	if (!http_proxy || !(len = strlen (http_proxy))) {
+		*ex = VD_ERR_PROXY;
+		return;
+	}
 
 	/* ignore the closing '/', if any */
 	if (http_proxy[len - 1] == '/')
@@ -447,8 +441,10 @@ vd_parse_http_proxy (const char* http_proxy, char **host, char **port)
 		}
 
 	/* port not found, or no space left for host */
-	if (i == 0) 
-		return 1;
+	if (i == 0) {
+		*ex = VD_ERR_PROXY;
+		return;
+	}
 	
 	/* rest of string is host */
 	if (i >= 7 && strncmp (http_proxy, "http://", 7) == 0) 
@@ -456,7 +452,7 @@ vd_parse_http_proxy (const char* http_proxy, char **host, char **port)
 	else 
 		*host = strndup (http_proxy, i);
 	
-	return *host ? 1 : 0;
+	*ex = *host ? VD_ERR_OK : VD_ERR_PROXY; 
 }
 
 
@@ -470,13 +466,13 @@ vd_error_string (int err)
 		return "Not found";
 	case VD_ERR_UNAVAILABLE:
 		return "Dictionary is currently unavailable";
-        case VD_ERR_CONNECT:
+	case VD_ERR_CONNECT:
 		return "Error connecting to site";
 	case VD_ERR_SOCKET:
 		return "Error creating socket";
 	case VD_ERR_PROXY:
 		return "Proxy error";
-        case VD_ERR_DNS:
+	case VD_ERR_DNS:
 		return "DNS error";
 	case VD_ERR_READ:
 		return  "Read error";
@@ -486,7 +482,7 @@ vd_error_string (int err)
 		return "Memory error";
 	case VD_ERR_POINTER:
 		return "Invalid pointer";
-        case VD_ERR_PARAM:
+         case VD_ERR_PARAM:
 		return "Parameter error";
 	default:
 		return "Unknown error";
